==> tmaid-2.5.3.tar.gz: tmaid-2.5.3/src/command.h <==
/*
    Text maid
    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __COMMAND_H__
#define __COMMAND_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:メニュー関数群                                                           *
*                                                                             *
******************************************************************************/
void
command_new (GtkWidget *widget,
             gpointer   user_data);


void
command_open (GtkWidget *widget,
              gpointer   user_data);


void
command_close (GtkWidget *widget,
               gpointer   user_data);


void
command_save (GtkWidget *widget,
              gpointer   user_data);


void
command_saveas (GtkWidget *widget,
                gpointer   user_data);


void
command_reload (GtkWidget *widget,
                gpointer   user_data);


void
command_print (GtkWidget *widget,
               gpointer   user_data);


void
command_property (GtkWidget *widget,
                  gpointer   user_data);


void
command_exit (GtkWidget *widget,
              gpointer   user_data);


void
command_undo (GtkWidget *widget,
              gpointer   user_data);


void
command_redo (GtkWidget *widget,
              gpointer   user_data);


void
command_cut (GtkWidget *widget,
             gpointer   user_data);


void
command_copy (GtkWidget *widget,
              gpointer   user_data);


void
command_paste (GtkWidget *widget,
               gpointer   user_data);


void
command_delete (GtkWidget *widget,
                gpointer   user_data);


void
command_margin (GtkWidget *widget,
                gpointer   user_data);


void
command_tab (GtkWidget *widget,
             gpointer   user_data);


void
command_valchr (GtkWidget *widget,
                gpointer   user_data);


void
command_jump (GtkWidget *widget,
              gpointer   user_data);


void
command_all (GtkWidget *widget,
             gpointer   user_data);


void
command_find (GtkWidget *widget,
              gpointer   user_data);


void
command_next (GtkWidget *widget,
              gpointer   user_data);


void
command_replace (GtkWidget *widget,
                 gpointer   user_data);


void
command_pref (GtkWidget *widget,
              gpointer   user_data);


void
command_format (GtkWidget *widget,
                gpointer   user_data);


void
command_version (GtkWidget *widget,
                 gpointer   user_data);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __COMMAND_H__ */

==> tmaid-2.6.1.tar.gz: tmaid-2.6.1/src/command.h <==
/*
    Text maid
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __COMMAND_H__
#define __COMMAND_H__


#include "tmaid.h"


G_BEGIN_DECLS


/******************************************************************************
*                                                                             *
* ja:メニュー関数群                                                           *
*                                                                             *
******************************************************************************/
void
command_new (GtkWidget *widget,
             gpointer   user_data);


void
command_open (GtkWidget *widget,
              gpointer   user_data);


void
command_close (GtkWidget *widget,
               gpointer   user_data);


void
command_save (GtkWidget *widget,
              gpointer   user_data);


void
command_saveas (GtkWidget *widget,
                gpointer   user_data);


void
command_reload (GtkWidget *widget,
                gpointer   user_data);


void
command_print (GtkWidget *widget,
               gpointer   user_data);


void
command_property (GtkWidget *widget,
                  gpointer   user_data);


void
command_exit (GtkWidget *widget,
              gpointer   user_data);


void
command_undo (GtkWidget *widget,
              gpointer   user_data);


void
command_redo (GtkWidget *widget,
              gpointer   user_data);


void
command_cut (GtkWidget *widget,
             gpointer   user_data);


void
command_copy (GtkWidget *widget,
              gpointer   user_data);


void
command_paste (GtkWidget *widget,
               gpointer   user_data);


void
command_delete (GtkWidget *widget,
                gpointer   user_data);


void
command_margin (GtkWidget *widget,
                gpointer   user_data);


void
command_tab (GtkWidget *widget,
             gpointer   user_data);


void
command_valchr (GtkWidget *widget,
                gpointer   user_data);


void
command_jump (GtkWidget *widget,
              gpointer   user_data);


void
command_all (GtkWidget *widget,
             gpointer   user_data);


void
command_find (GtkWidget *widget,
              gpointer   user_data);


void
command_next (GtkWidget *widget,
              gpointer   user_data);


void
command_replace (GtkWidget *widget,
                 gpointer   user_data);


void
command_pref (GtkWidget *widget,
              gpointer   user_data);


void
command_format (GtkWidget *widget,
                gpointer   user_data);


void
command_version (GtkWidget *widget,
                 gpointer   user_data);


G_END_DECLS


#endif /* __COMMAND_H__ */
